@@ -23,6 +23,7 @@ names = {  # (summary level value, base 10 chars,  Base 62 chars, prefix fields)
     'tract': 140,
     'blockgroup': 150,
     'block': 101,
+    'puma': 795, # Puma 5%
     'sdelm': 950,
     'sdsec': 960,
     'sduni': 970,
@@ -60,7 +61,7 @@ names = {  # (summary level value, base 10 chars,  Base 62 chars, prefix fields)
     'state_cbsa_metdiv_county': 324,
     'state_county_cousub_place': 70,
     'necta_state_county': 353,
-    'state_puma5': 795,
+
     'csa': 330,
     'csa_state': 331,
     'csa_cbsa': 332,
@@ -617,6 +618,11 @@ class Geoid(object):
                     raise ValueError("Failed to convert '{}' ({}) for field '{}' in {}: {}"
                                      .format(v, type(v), k, type(self), e))
 
+        if 'gc' in kwargs:
+            self.component = kwargs['gc']
+        else:
+            self.component = '00'
+
     def __str__(self):
 
         d = self.__dict__
